Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/cydrobolt/polr.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTarulia <takuja@gmx.de>2015-09-25 19:01:59 +0300
committerTarulia <takuja@gmx.de>2015-09-25 19:01:59 +0300
commitb49461d608e0f2c99c524a0682d47bd9d0e77936 (patch)
tree31b06d0e38463bcf32d7e7dab4dc69c5e950389a
parent1af17a2c2a7e95755761b16102ce8838b313acb2 (diff)
[debug] off: Disable error reporting completely; on: Enable E_ALL
-rw-r--r--lib-core.php8
1 files changed, 6 insertions, 2 deletions
diff --git a/lib-core.php b/lib-core.php
index bee2b84..a657a95 100644
--- a/lib-core.php
+++ b/lib-core.php
@@ -16,9 +16,13 @@
*/
@(require_once('config.php'));
include('version.php');
-$debug = false; // Set to 1 in order to enable debug mode (shows sensitive database info), use for troubleshooting
+// Set to TRUE to enable debug mode (shows sensitive database info), use for troubleshooting only!
+// Also enables PHP error reporting level E_ALL
+$debug = FALSE;
if ( $debug === FALSE ) {
- error_reporting(E_ERROR);
+ error_reporting( 0 );
+} else {
+ error_reporting( E_ALL );
}
$footer = "&copy; Copyright 2014 $wsn. Powered by <a href='http://github.com/cydrobolt/polr'>Polr</a> ver $version build $reldate";
$hidefooter = true; // Let's hide this for now